a
{
    text-decoration:none;
}
.wrap
{
    background:#0000007F;
    position:fixed;
    width:100%;
    height:100%;
    z-index:2000;
}
.link_text
{
    color:#0D6EFD;
    cursor:pointer;
}
.list-group-item
{
    background:rgba(255,255,255,0.0);
}
.table
{
    background:rgba(255,255,255,0.0);
}